@@ -7,7 +7,7 @@ use HTTP::Status qw/:constants/;
 use JSON::XS                             ();
 use Weather::NHC::TropicalCyclone::Storm ();
 
-our $VERSION                     = q{0.11};
+our $VERSION                     = q{0.12};
 our $DEFAULT_URL                 = q{https://www.nhc.noaa.gov/CurrentStorms.json};
 our $DEFAULT_RSS_ATLANTIC        = q{https://www.nhc.noaa.gov/index-at.xml};
 our $DEFAULT_RSS_EAST_PACIFIC    = q{https://www.nhc.noaa.gov/index-ep.xml};
@@ -23,8 +23,7 @@ sub new {
     my $self = {
         _obj => undef,
     };
-    bless $self, $pkg;
-    return $self;
+    return bless $self, $pkg;
 }
 
 sub fetch {
